package com.novapp.nova_alarm_plugin

import android.app.Activity
import android.content.Intent
import androidx.annotation.NonNull;
import com.novapp.nova_alarm_plugin.calendar.CalendarReminderUtils
import com.novapp.nova_alarm_plugin.utils.ClockPluginConstant.*
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

/** FlutterClockPlugin */
public class FlutterClockPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {


    override fun onDetachedFromActivity() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        appContext = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        val channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "nova_alarm_plugin")
        channel.setMethodCallHandler(FlutterClockPlugin())
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    companion object {
        val Tag = FlutterClockPlugin::class.java.name

        var appContext: Activity? = null

        var isStartClockService: Boolean = false

        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "flutter_clock_plugin")
            channel.setMethodCallHandler(FlutterClockPlugin())
        }
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {

        when (call.method) {
            initClockService -> initClockService()
            requestClockPermission -> {
                if (call.argument<Int>("type") == Calendar) {
                    CalendarReminderUtils.checkCalendarPermission(appContext)
                } else {

                }
            }
            setClock -> result.notImplemented()
            isClockAvailable -> result.notImplemented()
            cancelAllClock -> result.notImplemented()
            closeNotification -> result.notImplemented()
            showAndroidNotification -> showAlarmNotification(call)
            insertCalenderEvent -> CalendarReminderUtils.addCalendarEvent(appContext, call, result)
            deleteCalendarEvent -> CalendarReminderUtils.deleteCalendarEvent(appContext, call, result)

        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    }


    private fun initClockService() {
        appContext?.startService(Intent(appContext, KeepAliveService::class.java))
    }


    private fun showAlarmNotification(@NonNull call: MethodCall) {
        val notifyName = call.argument<String>("name")
        val content = call.argument<String>("content")

        val intent = Intent()
        intent.setClass(appContext, KeepAliveService::class.java)
        intent.putExtra("name", notifyName)
        intent.putExtra("content", content)
        appContext?.startService(intent)
    }

}
