package com.novapp.nova_alarm_plugin;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.app.TaskStackBuilder;
import android.content.Intent;
import android.os.Build;
import android.os.IBinder;
import android.util.Log;

import androidx.annotation.Nullable;
import androidx.core.app.NotificationCompat;

import com.novapp.nova_alarm_plugin.utils.ResourceUtils;

public class KeepAliveService extends Service {
    private static final String TAG = "DaemonService";
    public static final int NOTICE_ID = 100;

    @Override
    public void onCreate() {
        super.onCreate();
        Log.d(TAG,"KeepAliveService onCreate");
        try {
            Class<?> mainClass = Class.forName(getPackageName() + ".MainActivity");
            Intent intent = new Intent(this, mainClass);
            NotificationManager manager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
            //8.0 以后需要加上channelId 才能正常显示
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O){
                String channelId = "default";
                String channelName = "默认通知";
                manager.createNotificationChannel(new NotificationChannel(channelId, channelName, NotificationManager.IMPORTANCE_HIGH));
            }
            //设置TaskStackBuilder
            TaskStackBuilder stackBuilder = TaskStackBuilder.create(this);
            stackBuilder.addParentStack(mainClass);
            stackBuilder.addNextIntent(intent);
            PendingIntent pendingIntent = stackBuilder.getPendingIntent(0, PendingIntent.FLAG_UPDATE_CURRENT);
            Notification notification = new NotificationCompat.Builder(this, "default")
                    .setSmallIcon(ResourceUtils.getAppLogoId(this))
                    .setContentTitle("标题")
                    .setContentText("这是内容，点击我可以跳转")
                    .setAutoCancel(false)
                    .setOngoing(true)
                    .setDefaults(Notification.DEFAULT_ALL)
                    .setWhen(System.currentTimeMillis())
                    .setContentIntent(pendingIntent)
                    .build();
            manager.notify(1, notification);


        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        }



    }

    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {

        if (intent.getExtras()!=null){
            String name = intent.getExtras().getString("name");
            String content = intent.getExtras().getString("content");

        }
        return START_STICKY;
    }

    @Nullable
    @Override
    public IBinder onBind(Intent intent) {
       return null;
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        // 如果Service被杀死，干掉通知
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR2) {
            NotificationManager mManager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
            mManager.cancel(NOTICE_ID);
        }
        Log.d(TAG, "DaemonService---->onDestroy，前台service被杀死");
        // 重启自己
        Intent intent = new Intent(getApplicationContext(), KeepAliveService.class);
        startService(intent);
    }
}
