import 'dart:async';
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';
import 'package:android_alarm_manager/android_alarm_manager.dart';

class NovaAlarm {
  static const MethodChannel _channel =
      const MethodChannel('nova_alarm_plugin');


  //这个是用于定时器的前台服务
  //Android平台初始化定时器和前台Service
  static Future initialize() async {
    if (Platform.isAndroid) {
      WidgetsFlutterBinding.ensureInitialized();
      //初始化定时器
      await AndroidAlarmManager.initialize();
      //唤醒前台Service
      await _channel.invokeMethod('initClockService');
    }
  }

  //Android独有平台分割线 插入日历事件
  static Future insertCalenderEvent(
      num beginTime, String title, description, num previousDate,
      {bool repeatDay = false}) async {
    assert(beginTime != null);
    assert(title != null);
    assert(description != null);
    if (Platform.isAndroid) {
      var params = {
        "reminderTime": beginTime,
        "title": title,
        "description": description,
        "previousDate": previousDate,
        "repeatDay": repeatDay
      };
      return await _channel.invokeMethod('insertCalenderEvent', params);
    }
  }

  static Future deleteCalendarEvent(String title) async {
    if (Platform.isAndroid) {
      var params = {"title": title};
      await _channel.invokeMethod('deleteCalendarEvent', params);
    }
  }

  //申请设置闹钟所需权限
  static Future<bool> requestClockPermission() async {
    return await _channel.invokeMethod('requestClockPermission');
  }

  //判断闹钟是否可用
  static Future<bool> isClockAvailable() async {
    return await _channel.invokeMethod('isClockAvailable');
  }

  /// time 设置闹钟的时间戳   闹钟活动名activityName
  static Future<bool> setClock(String time, activityName,
      {String ringName, title, content, bool repeats}) async {
    var kParams = {
      "time": time,
      "activityId": activityName,
      "ringName": ringName,
      "title": title,
      "content": content,
      "repeats": repeats,
    };
    final bool isSuccess = await _channel.invokeMethod('setClock', kParams);
    return isSuccess;
  }

  static Future<bool> closeClock({String activityName}) async {
    var kParam = {"activityName": activityName};
    return await _channel.invokeMethod('cancelAllClock', kParam);
  }

  static Future<bool> closeNotification() async {
    if (Platform.isIOS) {
      return await _channel.invokeMethod('closeNotification');
    } else {
      return null;
    }
  }
}
